@@ -11,18 +11,14 @@
 
 #pragma once
 
+#include "kleo_export.h"
+
+#include <QStringList>
+
 #include <gpgme++/engineinfo.h>
 #include <gpgme++/key.h>
 
-/* Does the given object comply with DE_VS?  This macro can be used to
-   ensure that we can still build against older versions of GPGME
-   without cluttering the code with preprocessor conditionals.  */
-#define IS_DE_VS(x)	(x).isDeVs()
-
-#include "kleo_export.h"
-
 class QString;
-#include <QStringList>
 class QByteArray;
 
 namespace Kleo
@@ -44,9 +40,22 @@ KLEO_EXPORT bool gpg4winSignedversion();
 KLEO_EXPORT QString gpg4winDescription();
 KLEO_EXPORT QString gpg4winLongDescription();
 KLEO_EXPORT QString gnupgInstallPath();
-KLEO_EXPORT const QString& paperKeyInstallPath();
+KLEO_EXPORT const QString &paperKeyInstallPath();
 
+KLEO_EXPORT QString brandingWindowTitle();
+KLEO_EXPORT QString brandingIcon();
+
+/**
+ * Returns a list of filename globs of files in one of the whitelisted folders
+ * to watch for changes.
+ * \sa gnupgFolderWhitelist, Kleo::FileSystemWatcher
+ */
 KLEO_EXPORT QStringList gnupgFileWhitelist();
+/**
+ * Returns a list of absolute paths of folders to watch for changes.
+ * \sa gnupgFileWhitelist, Kleo::FileSystemWatcher
+ */
+KLEO_EXPORT QStringList gnupgFolderWhitelist();
 KLEO_EXPORT int makeGnuPGError(int code);
 
 KLEO_EXPORT bool engineIsVersion(int major, int minor, int patch, GpgME::Engine = GpgME::GpgConfEngine);
@@ -74,16 +83,15 @@ KLEO_EXPORT bool haveX509DirectoryServerConfigured();
 /* Use gnupgUsesDeVsCompliance() or gnupgIsDeVsCompliant() instead. */
 KLEO_DEPRECATED_EXPORT bool gpgComplianceP(const char *mode);
 
-/** Returns true, if compliance mode "de-vs" is configured for GnuPG.
- *  Note: It does not check whether the used GnuPG is actually compliant.
+/**
+ * Use Kleo::DeVSCompliance::isActive() instead.
  */
-KLEO_EXPORT bool gnupgUsesDeVsCompliance();
+KLEO_DEPRECATED_EXPORT bool gnupgUsesDeVsCompliance();
 
-/** Returns true, if compliance mode "de-vs" is configured for GnuPG and if
- *  GnuPG passes a basic compliance check, i.e. at least libgcrypt and the used
- *  RNG are compliant.
+/**
+ * Use Kleo::DeVSCompliance::isCompliant() instead.
  */
-KLEO_EXPORT bool gnupgIsDeVsCompliant();
+KLEO_DEPRECATED_EXPORT bool gnupgIsDeVsCompliant();
 
 KLEO_EXPORT enum GpgME::UserID::Validity keyValidity(const GpgME::Key &key);
 
